@@ -8,11 +8,11 @@ pytestmark = pytest.mark.unit
 
 def test_osidb():
     runner = CliRunner()
-    result = runner.invoke(cli, ["manage", "osidb"])
+    result = runner.invoke(cli, ["entities", "OSIDB", "admin"])
     assert result.exit_code == 0
 
 
 def test_corgi():
     runner = CliRunner()
-    result = runner.invoke(cli, ["manage", "corgi"])
+    result = runner.invoke(cli, ["entities", "CORGI", "admin"])
     assert result.exit_code == 0
